@@ -11,7 +11,8 @@ import pandas as pd
 
 
 class SF_Col_Input(InputData):
-    def __init__(self, input_data_path=None, process_name='SF_Col', CommonDataObjct=None):
+    def __init__(self, input_data_path=None, process_data_path=None,
+                 process_name='SF_Col', CommonDataObjct=None):
         if input_data_path:
             self.input_data_path = input_data_path
         else:
@@ -23,15 +24,11 @@ class SF_Col_Input(InputData):
         if not CommonDataObjct:
             CommonDataObjct = CommonData()
 
-        self.process_data = pd.read_csv(Path(__file__).parent / "Data/SF_Col_Input_MaterialDependent.csv",
-                                        index_col=0,
-                                        header=0,
-                                        skiprows=[1, 2, 3]).loc[CommonDataObjct.Index].astype(float)
-        self.process_data.fillna(0, inplace=True)
-        self.process_data_info = pd.read_csv(Path(__file__).parent / "Data/SF_Col_Input_MaterialDependent.csv",
-                                             index_col=0,
-                                             header=0,
-                                             nrows=3)
+        if process_data_path is None:
+            process_data_path = Path(__file__).parent / "Data/SF_Col_Input_MaterialDependent.csv"
+        self.add_process_data(process_data_path=process_data_path,
+                              index=CommonDataObjct.Index)
+
         ### Read input data
         self.col = pd.read_csv(Path(__file__).parent / 'Data/SF_Col_Input_process.csv',
                                index_col='Name',
