@@ -17,6 +17,8 @@ from .Reproc_Input import Reproc_Input
 from .SF_Col_Input import SF_Col_Input
 from .TS_Input import TS_Input
 from .HC_Input import HC_Input
+from .GC_Input import GC_Input
+from .RDF_Input import RDF_Input
 
 __all__ = [
     'MC',
@@ -31,7 +33,9 @@ __all__ = [
     'Reproc_Input',
     'SF_Col_Input',
     'TS_Input',
-    'HC_Input'
+    'HC_Input',
+    'GC_Input',
+    'RDF_Input',
 ]
 
-__version__ = '0.2.0'
+__version__ = '0.2.2'
